@@ -1,65 +1,4 @@
-# check if the file_spec() is returning the right object
-file_spec_func_valid <- function() {
-  path <- "R/"
-  pattern <- "\\.R$"
-  format <- "text"
-  recursive <- FALSE
-  ignore_case <- TRUE
-  all_files <- FALSE
-
-  fs_source <- file_spec(
-    path = path, pattern = pattern, format = format,
-    recursive = recursive, ignore_case = ignore_case, all_files = all_files
-  )
-
-  return(
-    fs_source$path == path
-    & fs_source$pattern == pattern
-    & fs_source$format == format
-    & fs_source$recursive == recursive
-    & fs_source$ignore_case == ignore_case
-    & fs_source$all_files == all_files
-    & class(fs_source) == "file_spec"
-  )
-}
-
-# flatten the structure of a file_spec list
-fs_unlist <- function(fs) {
-  fs_len <- length(fs)
-  ls <- list()
-  ls_cnt <- 0
-
-  if (fs_len) {
-    for (i in seq_len(fs_len)) {
-      x <- fs[[i]]
-      if (class(x) == "file_spec") {
-        ls_cnt <- ls_cnt + 1
-        ls[[ls_cnt]] <- x
-      }
-      else if (class(x) == "list") {
-        ls_tmp <- fs_unlist(x)
-        for (j in seq_len(length(ls_tmp))) {
-          ls_cnt <- ls_cnt + 1
-          ls[[ls_cnt]] <- ls_tmp[[j]]
-        }
-      }
-    }
-  }
-  ls
-}
-
-# check if a file_spec object has all of the parameters as specified
-is_file_spec_type <- function(fs_source, path, pattern, format, recursive, ignore_case, all_files) {
-  return(fs_source$path == path
-  & fs_source$pattern == pattern
-  & fs_source$format == format
-  & fs_source$recursive == recursive
-  & fs_source$ignore_case == ignore_case
-  & fs_source$all_files == all_files
-  & class(fs_source) == "file_spec")
-}
-
-testthat::test_that("file_root_core() creates the correct 'file_spec' object", {
+test_that("file_root_core() creates the correct 'file_spec' object", {
   is_root_core <- is_file_spec_type(
     fs_source = file_root_core(),
     path = "",
@@ -70,11 +9,10 @@ testthat::test_that("file_root_core() creates the correct 'file_spec' object", {
     all_files = TRUE
   )
 
-  testthat::expect_equal(is_root_core, TRUE)
+  expect_equal(is_root_core, TRUE)
 })
 
-
-testthat::test_that("file_root_all() creates the correct 'file_spec' object", {
+test_that("file_root_all() creates the correct 'file_spec' object", {
   is_root_all <- is_file_spec_type(
     fs_source = file_root_all(),
     path = "",
@@ -85,11 +23,10 @@ testthat::test_that("file_root_all() creates the correct 'file_spec' object", {
     all_files = TRUE
   )
 
-  testthat::expect_equal(is_root_all, TRUE)
+  expect_equal(is_root_all, TRUE)
 })
 
-
-testthat::test_that("file_r() creates the correct 'file_spec' objects", {
+test_that("file_r() creates the correct 'file_spec' objects", {
   fs_source <- file_r()
   is_spec_code <- FALSE
   is_spec_data <- FALSE
@@ -110,8 +47,7 @@ testthat::test_that("file_r() creates the correct 'file_spec' objects", {
       )
       ) {
         is_spec_code <- TRUE
-      }
-      else if
+      } else if
       (!is_spec_data & is_file_spec_type(
           fs_source = fs,
           path = "R/",
@@ -127,12 +63,11 @@ testthat::test_that("file_r() creates the correct 'file_spec' objects", {
     }
   }
 
-  testthat::expect_equal(is_spec_code, TRUE)
-  testthat::expect_equal(is_spec_data, TRUE)
+  expect_equal(is_spec_code, TRUE)
+  expect_equal(is_spec_data, TRUE)
 })
 
-
-testthat::test_that("file_man() creates the correct 'file_spec' objects", {
+test_that("file_man() creates the correct 'file_spec' objects", {
   fs_source <- file_man()
 
   is_spec_rd <- FALSE
@@ -155,8 +90,7 @@ testthat::test_that("file_man() creates the correct 'file_spec' objects", {
       )
       ) {
         is_spec_rd <- TRUE
-      }
-      else if
+      } else if
       (!is_spec_fig_binary & is_file_spec_type(
           fs_source = fs,
           path = "man/figures/",
@@ -168,8 +102,7 @@ testthat::test_that("file_man() creates the correct 'file_spec' objects", {
         )
       ) {
         is_spec_fig_binary <- TRUE
-      }
-      else if
+      } else if
       (!is_spec_fig_text & is_file_spec_type(
           fs_source = fs,
           path = "man/figures/",
@@ -185,13 +118,12 @@ testthat::test_that("file_man() creates the correct 'file_spec' objects", {
     }
   }
 
-  testthat::expect_equal(is_spec_rd, TRUE)
-  testthat::expect_equal(is_spec_fig_binary, TRUE)
-  testthat::expect_equal(is_spec_fig_text, TRUE)
+  expect_equal(is_spec_rd, TRUE)
+  expect_equal(is_spec_fig_binary, TRUE)
+  expect_equal(is_spec_fig_text, TRUE)
 })
 
-
-testthat::test_that("file_src() creates the correct 'file_spec' object", {
+test_that("file_src() creates the correct 'file_spec' object", {
   is_src <- is_file_spec_type(
     fs_source = file_src(),
     path = "src/",
@@ -202,11 +134,10 @@ testthat::test_that("file_src() creates the correct 'file_spec' object", {
     all_files = FALSE
   )
 
-  testthat::expect_equal(is_src, TRUE)
+  expect_equal(is_src, TRUE)
 })
 
-
-testthat::test_that("file_data() creates the correct 'file_spec' object", {
+test_that("file_data() creates the correct 'file_spec' object", {
   is_data <- is_file_spec_type(
     fs_source = file_data(),
     path = "data/",
@@ -217,11 +148,10 @@ testthat::test_that("file_data() creates the correct 'file_spec' object", {
     all_files = FALSE
   )
 
-  testthat::expect_equal(is_data, TRUE)
+  expect_equal(is_data, TRUE)
 })
 
-
-testthat::test_that("file_vignettes() creates the correct 'file_spec' objects", {
+test_that("file_vignettes() creates the correct 'file_spec' objects", {
   fs_source <- file_vignettes()
   is_spec_text <- FALSE
   is_spec_binary <- FALSE
@@ -242,8 +172,7 @@ testthat::test_that("file_vignettes() creates the correct 'file_spec' objects",
       )
       ) {
         is_spec_text <- TRUE
-      }
-      else if
+      } else if
       (!is_spec_binary & is_file_spec_type(
           fs_source = fs,
           path = "vignettes/",
@@ -259,12 +188,11 @@ testthat::test_that("file_vignettes() creates the correct 'file_spec' objects",
     }
   }
 
-  testthat::expect_equal(is_spec_text, TRUE)
-  testthat::expect_equal(is_spec_binary, TRUE)
+  expect_equal(is_spec_text, TRUE)
+  expect_equal(is_spec_binary, TRUE)
 })
 
-
-testthat::test_that("file_default() creates the correct 'file_spec' objects", {
+test_that("file_default() creates the correct 'file_spec' objects", {
   fs_source <- file_default()
   # linearize the file_spec list
   fs_ls <- fs_unlist(fs_source)
@@ -295,8 +223,7 @@ testthat::test_that("file_default() creates the correct 'file_spec' objects", {
       )
       ) {
         is_root_core <- TRUE
-      }
-      else if (!is_spec_code & is_file_spec_type(
+      } else if (!is_spec_code & is_file_spec_type(
         fs_source = fs,
         path = "R/",
         pattern = "\\.R$|\\.r$|\\.s$|\\.q$",
@@ -307,8 +234,7 @@ testthat::test_that("file_default() creates the correct 'file_spec' objects", {
       )
       ) {
         is_spec_code <- TRUE
-      }
-      else if
+      } else if
       (!is_spec_data & is_file_spec_type(
           fs_source = fs,
           path = "R/",
@@ -320,8 +246,7 @@ testthat::test_that("file_default() creates the correct 'file_spec' objects", {
         )
       ) {
         is_spec_data <- TRUE
-      }
-      else if (!is_spec_rd & is_file_spec_type(
+      } else if (!is_spec_rd & is_file_spec_type(
         fs_source = fs,
         path = "man/",
         pattern = "\\.Rd$|\\.rd$",
@@ -332,8 +257,7 @@ testthat::test_that("file_default() creates the correct 'file_spec' objects", {
       )
       ) {
         is_spec_rd <- TRUE
-      }
-      else if
+      } else if
       (!is_spec_fig_binary & is_file_spec_type(
           fs_source = fs,
           path = "man/figures/",
@@ -345,8 +269,7 @@ testthat::test_that("file_default() creates the correct 'file_spec' objects", {
         )
       ) {
         is_spec_fig_binary <- TRUE
-      }
-      else if
+      } else if
       (!is_spec_fig_text & is_file_spec_type(
           fs_source = fs,
           path = "man/figures/",
@@ -358,8 +281,7 @@ testthat::test_that("file_default() creates the correct 'file_spec' objects", {
         )
       ) {
         is_spec_fig_text <- TRUE
-      }
-      else if
+      } else if
       (!is_src & is_file_spec_type(
           fs_source = fs,
           path = "src/",
@@ -371,9 +293,7 @@ testthat::test_that("file_default() creates the correct 'file_spec' objects", {
         )
       ) {
         is_src <- TRUE
-      }
-
-      else if (!is_spec_text & is_file_spec_type(
+      } else if (!is_spec_text & is_file_spec_type(
         fs_source = fs,
         path = "vignettes/",
         pattern = "\\.R$|\\.r$|\\.s$|\\.q$|\\.Rd$|\\.rd$|\\.svg$|\\.c$|\\.h$|\\.cpp$|\\.cc$|\\.hpp$|\\.hxx$|\\.hh$|\\.f$|\\.f90$|\\.f95$|\\.f03$|\\.win$|\\.in$|\\.ucrt$|\\.ac$|\\.Rmd$|\\.md$|\\.csl$|\\.Rnw$|\\.tex$|\\.ltx$|\\.rsp$|\\.cls$|\\.sty$|\\.bib$|\\.bst$|\\.asis$|\\.el$|\\.Rproj$|\\.dcf$|\\.yml$|\\.yaml$|\\.note$|\\.csv$|\\.tsv$|\\.txt$|\\.html$|\\.htm$|\\.shtml$|\\.css$|\\.js$|\\.json$|\\.xml$|\\.scss$|\\.less$|\\.rtf$|\\.save$|\\.Rout$|\\.stan$|\\.bug$|\\.jags$|\\.py$|\\.ipynb$|\\.sh$|\\.java$|\\.bat$|\\.m4$|\\.cmake$|\\.sql$|\\.lua$|\\.rs$|\\.jl$|\\.pl$|\\.pm$|\\.brew$|\\.po$|\\.pot$|\\.geojson$|\\.kml$|\\.prj$|\\.cpg$|\\.qpj$|\\.fasta$|\\.fastq$|\\.vcf$|\\.ped$|\\.bim$|\\.fam$|\\.gff$|\\.gtf$",
@@ -384,8 +304,7 @@ testthat::test_that("file_default() creates the correct 'file_spec' objects", {
       )
       ) {
         is_spec_text <- TRUE
-      }
-      else if
+      } else if
       (!is_spec_binary & is_file_spec_type(
           fs_source = fs,
           path = "vignettes/",
@@ -397,8 +316,7 @@ testthat::test_that("file_default() creates the correct 'file_spec' objects", {
         )
       ) {
         is_spec_binary <- TRUE
-      }
-      else if
+      } else if
       (!is_data & is_file_spec_type(
           fs_source = fs,
           path = "data/",
@@ -415,20 +333,20 @@ testthat::test_that("file_default() creates the correct 'file_spec' objects", {
   }
 
 
-  testthat::expect_equal(is_root_core, TRUE)
-  testthat::expect_equal(is_spec_code, TRUE)
-  testthat::expect_equal(is_spec_data, TRUE)
-  testthat::expect_equal(is_spec_rd, TRUE)
-  testthat::expect_equal(is_spec_fig_binary, TRUE)
-  testthat::expect_equal(is_spec_fig_text, TRUE)
-  testthat::expect_equal(is_src, TRUE)
-  testthat::expect_equal(is_spec_text, TRUE)
-  testthat::expect_equal(is_spec_binary, TRUE)
-  testthat::expect_equal(is_data, TRUE)
+  expect_equal(is_root_core, TRUE)
+  expect_equal(is_spec_code, TRUE)
+  expect_equal(is_spec_data, TRUE)
+  expect_equal(is_spec_rd, TRUE)
+  expect_equal(is_spec_fig_binary, TRUE)
+  expect_equal(is_spec_fig_text, TRUE)
+  expect_equal(is_src, TRUE)
+  expect_equal(is_spec_text, TRUE)
+  expect_equal(is_spec_binary, TRUE)
+  expect_equal(is_data, TRUE)
 })
 
 
-testthat::test_that("file_ectd() creates the correct 'file_spec' objects", {
+test_that("file_ectd() creates the correct 'file_spec' objects", {
   fs_source <- file_ectd()
   # linearize the file_spec list
   fs_ls <- fs_unlist(fs_source)
@@ -457,8 +375,7 @@ testthat::test_that("file_ectd() creates the correct 'file_spec' objects", {
       )
       ) {
         is_root_core <- TRUE
-      }
-      else if (!is_spec_code & is_file_spec_type(
+      } else if (!is_spec_code & is_file_spec_type(
         fs_source = fs,
         path = "R/",
         pattern = "\\.R$|\\.r$|\\.s$|\\.q$",
@@ -469,8 +386,7 @@ testthat::test_that("file_ectd() creates the correct 'file_spec' objects", {
       )
       ) {
         is_spec_code <- TRUE
-      }
-      else if
+      } else if
       (!is_spec_data & is_file_spec_type(
           fs_source = fs,
           path = "R/",
@@ -482,8 +398,7 @@ testthat::test_that("file_ectd() creates the correct 'file_spec' objects", {
         )
       ) {
         is_spec_data <- TRUE
-      }
-      else if (!is_spec_rd & is_file_spec_type(
+      } else if (!is_spec_rd & is_file_spec_type(
         fs_source = fs,
         path = "man/",
         pattern = "\\.Rd$|\\.rd$",
@@ -494,8 +409,7 @@ testthat::test_that("file_ectd() creates the correct 'file_spec' objects", {
       )
       ) {
         is_spec_rd <- TRUE
-      }
-      else if
+      } else if
       (!is_spec_fig_binary & is_file_spec_type(
           fs_source = fs,
           path = "man/figures/",
@@ -507,8 +421,7 @@ testthat::test_that("file_ectd() creates the correct 'file_spec' objects", {
         )
       ) {
         is_spec_fig_binary <- TRUE
-      }
-      else if
+      } else if
       (!is_spec_fig_text & is_file_spec_type(
           fs_source = fs,
           path = "man/figures/",
@@ -520,8 +433,7 @@ testthat::test_that("file_ectd() creates the correct 'file_spec' objects", {
         )
       ) {
         is_spec_fig_text <- TRUE
-      }
-      else if
+      } else if
       (!is_src & is_file_spec_type(
           fs_source = fs,
           path = "src/",
@@ -533,8 +445,7 @@ testthat::test_that("file_ectd() creates the correct 'file_spec' objects", {
         )
       ) {
         is_src <- TRUE
-      }
-      else if
+      } else if
       (!is_data & is_file_spec_type(
           fs_source = fs,
           path = "data/",
@@ -550,17 +461,17 @@ testthat::test_that("file_ectd() creates the correct 'file_spec' objects", {
     }
   }
 
-  testthat::expect_equal(is_root_core, TRUE)
-  testthat::expect_equal(is_spec_code, TRUE)
-  testthat::expect_equal(is_spec_data, TRUE)
-  testthat::expect_equal(is_spec_rd, TRUE)
-  testthat::expect_equal(is_spec_fig_binary, TRUE)
-  testthat::expect_equal(is_spec_fig_text, TRUE)
-  testthat::expect_equal(is_src, TRUE)
-  testthat::expect_equal(is_data, TRUE)
+  expect_equal(is_root_core, TRUE)
+  expect_equal(is_spec_code, TRUE)
+  expect_equal(is_spec_data, TRUE)
+  expect_equal(is_spec_rd, TRUE)
+  expect_equal(is_spec_fig_binary, TRUE)
+  expect_equal(is_spec_fig_text, TRUE)
+  expect_equal(is_src, TRUE)
+  expect_equal(is_data, TRUE)
 })
 
-testthat::test_that("file_auto() creates the correct 'file_spec' objects", {
+test_that("file_auto() creates the correct 'file_spec' objects", {
   fs_source <- file_auto("inst/")
   is_spec_text <- FALSE
   is_spec_binary <- FALSE
@@ -581,8 +492,7 @@ testthat::test_that("file_auto() creates the correct 'file_spec' objects", {
       )
       ) {
         is_spec_text <- TRUE
-      }
-      else if
+      } else if
       (!is_spec_binary & is_file_spec_type(
           fs_source = fs,
           path = "inst/",
@@ -598,22 +508,22 @@ testthat::test_that("file_auto() creates the correct 'file_spec' objects", {
     }
   }
 
-  testthat::expect_equal(is_spec_text, TRUE)
-  testthat::expect_equal(is_spec_binary, TRUE)
+  expect_equal(is_spec_text, TRUE)
+  expect_equal(is_spec_binary, TRUE)
 })
 
-testthat::test_that("cat_patterns() generate the right string pattern", {
+test_that("cat_patterns() generate the right string pattern", {
   str <- c("x", "y", "z")
   str_target <- "x|y|z"
   str_source <- cat_patterns(str)
 
-  testthat::expect_equal(str_source, str_target)
+  expect_equal(str_source, str_target)
 })
 
-testthat::test_that("ends_with() generate the right string pattern", {
+test_that("ends_with() generate the right string pattern", {
   str <- c("x", "y", "z")
   str_target <- c("\\.x$", "\\.y$", "\\.z$")
   str_source <- ends_with(str)
 
-  testthat::expect_equal(str_source, str_target)
+  expect_equal(str_source, str_target)
 })
